@@ -1979,7 +1979,7 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
    bboxin[1].y = theobject->bbox.lowerleft.y + theobject->bbox.height; 
    if (level == 0)
       extendschembbox(theinstance, &(bboxin[0]), &(bboxin[1]));
-   UTransformbyCTM(DCTM, &bboxin, &bboxout, 2);
+   UTransformbyCTM(DCTM, bboxin, bboxout, 2);
 
    xm = (bboxout[0].x < bboxout[1].x) ? 0 : 1;  
    ym = (bboxout[0].y < bboxout[1].y) ? 0 : 1;  
